import { SDSSelectedResultConfiguration } from '../../selected-result/models/SDSSelectedResultConfiguration';
import { SDSAutocompleteSearchConfiguration } from '../../autocomplete-search/models/SDSAutocompleteConfiguration';
import { SelectionMode } from '../../selected-result/models/sds-selected-item-model-helper';
import { Observable } from 'rxjs';
export declare class SDSAutocompletelConfiguration implements SDSSelectedResultConfiguration, SDSAutocompleteSearchConfiguration {
    /**
     * sets the default debounce time to 250 milliseconds
     */
    constructor();
    /**
     * Used to describe the drop down (Text should match the label that will be supplied)
     */
    labelText: string;
    /**
     * Used for the Id of the control
     */
    id: string;
    /**
     *  This is the primary field used to identify each object in the results
     */
    primaryKeyField: string;
    /**
     *  Property from supplied model used for the top part of the basic template
     */
    primaryTextField: string;
    /**
     *  Property from supplied model used for the bottom part of the basic template
     */
    secondaryTextField: string;
    /**
     *  Sets the time waited for addional key actions Default is 250 milliseconds
     */
    debounceTime: number;
    /**
     * Place holder text for autocomplete input
     */
    autocompletePlaceHolderText: string;
    /**
     * Mininumn Characters for search
     */
    minimumCharacterCountSearch: number;
    /**
     * Mode of the model either allows a single item or multiple items
     */
    selectionMode: SelectionMode;
    /**
     * Allows option to allow user text not in the standard results
     */
    isFreeTextEnabled: boolean;
    /**
     * Text appeneded ad the end of free text
     */
    freeTextSubtext: string;
    /**
     * Focus into autocomplete search
     */
    focusInSearch: boolean;
    /**
     * The aria-label for the auto-complete
     */
    ariaLabelText: string;
    /**
     * To enable the tag mode
     */
    isTagModeEnabled: boolean;
    /**
     * To make input readonly
     */
    inputReadOnly: boolean;
    /**
     * Name of the children filed
     */
    groupByChild: string;
    /**
     * To enable the Grouping mode
     */
    isGroupingEnabled: boolean;
    /**
     * To enable the Group item selectable
     */
    isSelectableGroup: boolean;
    /**
     * Toggle whether or not to display chips. This can be useful if some custom UI is used
     * for rendering autocomplete values in multi-select mode
     * @default false
     */
    hideChips: boolean;
    /**
     * Modifiier function to change display of how primary text field is shown
     * Allows adding prefix / suffix values when displaying tags
     */
    displayModifierFn: (displayValue: string, index?: number) => string;
    /**
     * Provides a way for external components to force change detection
     * on internal components. Any time this observable is emitted, a change
     * detection will be preformed, ensuring data model and template values are
     * in sync. This can be useful if some external changes are made and visual
     * updates need to be made
     */
    registerChanges$: Observable<void>;
    hideCloseIcon: boolean;
    useCheckBoxes: boolean;
}
