import { AfterContentInit, EventEmitter, OnChanges, OnInit, QueryList, SimpleChanges } from '@angular/core';
import { TabPanelComponent } from './tab-panel.component';
import * as i0 from "@angular/core";
export declare class TabsComponent implements OnInit, OnChanges, AfterContentInit {
    /**
     * Currently selected tab for display.
     */
    selectedTab: TabPanelComponent;
    /**
     * Enable automatic activation for tabs when cycling through tabs using
     * Left or Right arrow keys. Automatic activated tabs will automatically
     * be selected on focus as user presses left or right arrow to move
     * through each tab. By default, tabs will need to be manually selected
     * when using keyboard only by pressing either Enter or Space to select
     * the focused tab
     */
    automaticActivation: boolean;
    /**
     * CSS styling class for tabs
     */
    tabClass: string;
    interceptTabChange: boolean;
    /**
     * Emits an event whenever a tab is selected by the user containing the selected
     * TabPanelComponent. Please note that because this output contains `Change` suffix
     * to the `tabSelected` input, users can 2-way bind to the `selectedTab` input
     */
    selectedTabChange: EventEmitter<TabPanelComponent>;
    preTabChange: EventEmitter<TabPanelComponent>;
    tabPanels: QueryList<TabPanelComponent>;
    /**
     * Currently focused tab - can differ from selected tab when tab panels are manually activated
     */
    private focusedTab;
    /**
     * Assigns selected tab value was given. Otherwise, the first
     * tab panel in the list will be selected after content has initialized.
     */
    ngOnInit(): void;
    /**
     * Listens for programmatic change to selected tab. When a tab is changed
     * programmatically, we must disable previously selected tab, set selected
     * property of the new tab to true, and adjust bookkeeping values.
     */
    ngOnChanges(changes: SimpleChanges): void;
    /**
     * If user has not given any tabs to select initially,
     * select the first tab panel.
     */
    ngAfterContentInit(): void;
    onTabClicked(clickEvent: MouseEvent, tabPanel: TabPanelComponent): void;
    /**
     * Looks for Left and Right arrow presses and moves selected tab accordingly.
     * @param $event - Keyboard Event
     */
    onKeyDown($event: any): void;
    isObj(obj: any): boolean;
    /**
     * Internal method to change currently selected tab panel and display another panel
     * to the user. External components should not use this method, but rather
     * two-way bind the selectedTab input and modify that value.
     * @param newTabPanel
     */
    private changeSelectedTabPanel;
    /**
     * Gets next tab panel to the left of currently selected panel when Left Arrow is pressed.
     * Skips disabled panels until it finds next left panel that is not disabled
     * @param tabPanels - List of TabPanelComponents in the tab group
     * @param startIndex - Current index of focused tab panel
     */
    private getNextTabLeft;
    /**
     * Gets next tab panel to the right of currently selected panel when Right Arrow is pressed
     * Skips disabled panels until it finds next right panel that is not disabled
     * @param tabPanels - List of TabPanelComponents in the tab group
     * @param startIndex - Current index of focused tab panel
     */
    private getNextTabRight;
    static ɵfac: i0.ɵɵFactoryDeclaration<TabsComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<TabsComponent, "sds-tabs", never, { "selectedTab": { "alias": "selectedTab"; "required": false; }; "automaticActivation": { "alias": "automaticActivation"; "required": false; }; "tabClass": { "alias": "tabClass"; "required": false; }; "interceptTabChange": { "alias": "interceptTabChange"; "required": false; }; }, { "selectedTabChange": "selectedTabChange"; "preTabChange": "preTabChange"; }, ["tabPanels"], ["*"], false, never>;
}
