import { ChangeDetectorRef, ElementRef, EventEmitter, NgZone, TemplateRef } from '@angular/core';
import { SdsTreeTableData } from './tree-table.model';
import * as i0 from "@angular/core";
export declare class SdsTreeTableRow {
    templateRef: TemplateRef<any>;
    constructor(templateRef: TemplateRef<any>);
    static ɵfac: i0.ɵɵFactoryDeclaration<SdsTreeTableRow, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<SdsTreeTableRow, "[sdsTreeTableRow]", never, {}, {}, never, never, false, never>;
}
export declare class SdsTreeTableComponent {
    private elementRef;
    cdr: ChangeDetectorRef;
    private ngZone;
    /** Rows of table tada to display */
    dataSource: SdsTreeTableData[];
    /** Column header text */
    displayColumns: string[];
    /**
     * Defines maximum number of children to show to the user
     * IE - if a row has 20 children available, and childrenLimit
     * value is 10, then the amount of children displayed to the
     * user will be numChildrenToDisplay amount, and the rest
     * is toggled behind a 'View All' button,
     * This should be greater than or equal to numChildrenToDisplay
     * @default - Number.MAX_SAFE_INTEGER
     */
    childrenLimit: number;
    /**
     * Number of children to Display to users if a row's children length
     * exceeds childrenLimit. This should be less than or equal to childrenLimit
     *
     * General Cases:
     * If numChildrenToDisplay is 5, childrenLimit is 10, and row has 20 children
     *  5 children will be shown and the remaining can be displayed through View All button
     *
     * If numChildrenToDisplay is 5, childrenLimit is 10, and row has 10 children
     *  All 10 children will be displayed because the row's children does not exceed childrenLimit
     *
     * If numChildren is 5, childrenLimit is 10, and row has 4 children
     *  All 4 children will be displayed because row's children does not exceed childrenLimit
     *
     * @default - Number.MAX_SAFE_INTEGER
     */
    numChildrenToDisplay: number;
    /**
     * Reference for content projection. User defined values for how to
     * display each cell in a row
     */
    treetableRow: SdsTreeTableRow;
    /** Emitted for a row if there are more children to display and user clicked view all */
    viewAll: EventEmitter<any>;
    /** Emitted anytime a row 's expansion / collapse value changes */
    rowExpanded: EventEmitter<any>;
    _selectedRow: any;
    _selectedRowParent: any;
    constructor(elementRef: ElementRef, cdr: ChangeDetectorRef, ngZone: NgZone);
    /**
     * Public Interface - close all opened children
     */
    collapseAll(): void;
    /**
     * Public interface - open all panels with children
     */
    expandAll(): void;
    /**
     * Public interface - expand a single row given an ID.
     * The row's predecessors will also be expanded
     * @param rowId - id of row to expand
     */
    expandRow(rowId: string): void;
    /**
     * Public Interface - Collapse a single row given an id.
     * The row's successors will also be collapsed
     * @param rowId - id of row to collapse
     */
    collapseRow(rowId: string): void;
    viewAllClicked(row: SdsTreeTableData, currentRow: HTMLTableRowElement, tableRow: HTMLTableRowElement): void;
    private moreChildrenThanShowing;
    private moreChildrenThanInitialLimit;
    private toggleAllHelper;
    private expandRowHelper;
    private findRow;
    private collapseRowHelper;
    /** Sets height of vertical border on the tree table view */
    setHeight(row: HTMLTableRowElement, parentRow: HTMLTableRowElement, border: HTMLSpanElement): void;
    /**
     * Defines whether or not to display vertical border from this row. Vertical borders generally
     * start from the last child and extend to the parent. However, if we are truncating the number
     * of children displayed, then the vertical border would need to start from the child we
     * truncate at.
     * */
    displayVerticalBorder(parentRow: SdsTreeTableData, index: number, siblingRows: SdsTreeTableRow[]): boolean;
    getTemplateContext(parent: any, row: any, index: number, level: number, parentSelected?: boolean, parentRow?: HTMLTableRowElement): {
        row: any;
        level: number;
        index: number;
        size: any;
        rows: any;
        parentSelected: boolean;
        parent: any;
        parentRow: HTMLTableRowElement;
    };
    onRowClicked(row: SdsTreeTableData, tableRow: HTMLTableRowElement): void;
    onKeyDown($event: KeyboardEvent, tableRow: HTMLTableRowElement): void;
    getParentOfRow(allRows: any[], row: any): any;
    static ɵfac: i0.ɵɵFactoryDeclaration<SdsTreeTableComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SdsTreeTableComponent, "sds-tree-table", never, { "dataSource": { "alias": "dataSource"; "required": false; }; "displayColumns": { "alias": "displayColumns"; "required": false; }; "childrenLimit": { "alias": "childrenLimit"; "required": false; }; "numChildrenToDisplay": { "alias": "numChildrenToDisplay"; "required": false; }; }, { "viewAll": "viewAll"; "rowExpanded": "rowExpanded"; }, ["treetableRow"], never, false, never>;
}
